@@ -12,7 +12,7 @@ use crate::util::*;
 
 #[async_trait]
 pub trait KeyRange: Sync + Send {
-    async fn get_by_key_range(&self, f_para: &KeyCondition) -> Result<Vec<Instance>>;
+    async fn get_by_key_range(&self, f_para: &InsCond) -> Result<Vec<Instance>>;
 }
 
 lazy_static! {
@@ -39,7 +39,7 @@ impl InstanceDaoImpl {
     }
 
     /// check whether source stored earlier
-    pub async fn get_by_from(f_para: &IDAndFrom) -> Result<Option<Instance>> {
+    pub async fn select_by_from(f_para: &IDAndFrom) -> Result<Option<Instance>> {
         let sql = r"SELECT meta, ins_id, para, content, context, states, state_version, create_time, sys_context, from_key
             FROM instances
             where meta = :meta and ins_id = :ins_id and from_key = :from_key
@@ -60,7 +60,7 @@ impl InstanceDaoImpl {
     }
 
     /// get all downstream by `from`
-    pub async fn get_downstream(from: &str) -> Result<Vec<Instance>> {
+    pub async fn select_downstream(from: &str) -> Result<Vec<Instance>> {
         let sql = r"SELECT meta, ins_id, para, content, context, states, state_version, create_time, sys_context, from_key
             FROM instances
             where from_key = :from_key";
@@ -76,7 +76,7 @@ impl InstanceDaoImpl {
         Ok(rtn)
     }
 
-    async fn get_last_state(f_para: &KeyCondition) -> Result<Option<Instance>> {
+    async fn select_last_state(f_para: &InsCond) -> Result<Option<Instance>> {
         let sql = r"SELECT meta, ins_id, para, content, context, states, state_version, create_time, sys_context, from_key
             FROM instances
             where meta = :meta and ins_id = :ins_id and para = :para
@@ -84,7 +84,7 @@ impl InstanceDaoImpl {
             limit 1";
         let p = params! {
             "meta" => f_para.meta.to_string(),
-            "ins_id" => f_para.get_id()?,
+            "ins_id" => f_para.id,
             "para" => f_para.para.to_string(),
         };
         let rtn = MySql::fetch(sql, p, RawInstance::from).await?;
@@ -95,7 +95,7 @@ impl InstanceDaoImpl {
         }
     }
 
-    pub async fn get_by_id(f_para: KeyCondition) -> Result<Option<Instance>> {
+    pub async fn select_by_id(f_para: InsCond) -> Result<Option<Instance>> {
         let sql = r"SELECT meta, ins_id, para, content, context, states, state_version, create_time, sys_context, from_key
             FROM instances
             where meta = :meta and ins_id = :ins_id and para = :para and state_version = :state_version
@@ -103,8 +103,8 @@ impl InstanceDaoImpl {
             limit 1";
         let p = params! {
             "meta" => f_para.meta.to_string(),
-            "ins_id" => f_para.get_id()?,
-            "para" => f_para.para,
+            "ins_id" => f_para.id,
+            "para" => f_para.para.to_string(),
             "state_version" => f_para.state_version,
         };
         let rtn = MySql::fetch(sql, p, RawInstance::from).await?;
@@ -115,12 +115,12 @@ impl InstanceDaoImpl {
         }
     }
 
-    pub async fn delete(ins: &Instance) -> Result<u64> {
+    pub async fn delete(ins: &InstanceLocator) -> Result<u64> {
         let sql = r"DELETE FROM instances
             WHERE meta = :meta and ins_id = :ins_id and para = :para";
         let p = params! {
             "meta" => ins.meta.to_string(),
-            "ins_id" => ins.get_id()?,
+            "ins_id" => ins.id,
             "para" => ins.para.to_string(),
         };
         let rtn = MySql::idu(sql, p).await?;
@@ -129,13 +129,13 @@ impl InstanceDaoImpl {
     }
 
     /// get downstream instance through upstream instance
-    pub async fn get_last_target(from: &Instance, mission: &mut Mission) -> Result<Option<Instance>> {
+    pub async fn select_last_target(from: &Instance, mission: &mut Mission) -> Result<Option<Instance>> {
         // init for MetaType::loop --------------------
         if mission.to.get_meta_type() == MetaType::Loop
-            && mission.to.meta_string() == from.meta {
+            && mission.to.meta_string() == from.path.meta {
             if let Some(setting) = mission.to.get_setting() {
                 if setting.only_one {
-                    debug!("make MetaType::Loop as last state for {}", from.meta);
+                    debug!("make MetaType::Loop as last state for {}", from.path.meta);
                     return Ok(Some(from.clone()));
                 }
             }
@@ -146,7 +146,7 @@ impl InstanceDaoImpl {
         }
         let para_part = &mission.target_demand.append_para;
         let para_id = if para_part.len() > 0 {
-            let id = get_para_and_key_from_para(&from.para, para_part)?.0;
+            let id = get_para_and_key_from_para(&from.path.para, para_part)?.0;
             mission.sys_context.insert(CONTEXT_TARGET_INSTANCE_PARA.to_string(), id.to_string());
             id
         } else {
@@ -156,7 +156,7 @@ impl InstanceDaoImpl {
             // context have target id
             Some(state_id) => state_id.to_string(),
             None => {
-                if mission.use_upstream_id || mission.to.check_master(&from.meta) {
+                if mission.use_upstream_id || mission.to.check_master(&from.path.meta) {
                     let from_id = format!("{}", from.id);
                     mission.sys_context.insert(CONTEXT_TARGET_INSTANCE_ID.to_string(), from_id.to_string());
                     from_id
@@ -167,8 +167,8 @@ impl InstanceDaoImpl {
         };
         let meta = mission.to.meta_string();
         debug!("get last state for meta {}", &meta);
-        let qc = KeyCondition::new(&id, &meta, &para_id, 0);
-        Self::get_last_state(&qc).await
+        let qc = InsCond::new(id.parse()?, &meta, &para_id, 0);
+        Self::select_last_state(&qc).await
     }
 
     pub async fn meta_exists(meta: &str) -> Result<bool> {
@@ -188,7 +188,7 @@ fn raw_to_number(row: Row) -> i32 {
 #[async_trait]
 impl KeyRange for InstanceDaoImpl {
     /// ins_key > and between time range
-    async fn get_by_key_range(&self, f_para: &KeyCondition) -> Result<Vec<Instance>> {
+    async fn get_by_key_range(&self, f_para: &InsCond) -> Result<Vec<Instance>> {
         let mut list: Vec<String> = vec![];
         // used to avoid repeat add conditions
         let mut set: HashSet<String> = HashSet::new();
@@ -332,8 +332,8 @@ mod test {
     #[allow(dead_code)]
     fn get_last_state_test() {
         env::set_var("DATABASE_URL", "mysql://root@localhost/nature");
-        let para = KeyCondition::new("0", "B:score/trainee/all-subject:1", "002", 0);
-        let result = Runtime::new().unwrap().block_on(InstanceDaoImpl::get_last_state(&para));
+        let para = InsCond::new(0, "B:score/trainee/all-subject:1", "002", 0);
+        let result = Runtime::new().unwrap().block_on(InstanceDaoImpl::select_last_state(&para));
         let _ = dbg!(result);
     }
 
@@ -342,20 +342,22 @@ mod test {
     #[allow(dead_code)]
     fn query_by_id() {
         env::set_var("DATABASE_URL", "mysql://root@localhost/nature");
-        let para = KeyCondition {
-            id: "12345".to_string(),
-            meta: "B:sale/order:1".to_string(),
-            key_gt: "".to_string(),
-            key_ge: "".to_string(),
-            key_lt: "".to_string(),
-            key_le: "".to_string(),
-            para: "".to_string(),
-            state_version: 0,
+        let para = InsCond {
+            id: 12345,
             time_ge: None,
             time_lt: None,
-            limit: 1,
+            other: NoIdCond {
+                meta: "B:sale/order:1".to_string(),
+                key_gt: "".to_string(),
+                key_ge: "".to_string(),
+                key_lt: "".to_string(),
+                key_le: "".to_string(),
+                para: "".to_string(),
+                state_version: 0,
+                limit: 1,
+            },
         };
-        let result = Runtime::new().unwrap().block_on(InstanceDaoImpl::get_by_id(para));
+        let result = Runtime::new().unwrap().block_on(InstanceDaoImpl::select_by_id(para));
         let _ = dbg!(result);
     }
 
@@ -365,24 +367,26 @@ mod test {
     async fn query_by_range_test() {
         env::set_var("DATABASE_URL", "mysql://root@localhost/nature");
         let mut ins = Instance::new("sale/order").unwrap();
-        ins.id = "760228".to_string();
+        ins.id = 760228;
         let _ = InstanceDaoImpl::insert(&ins).await;
 
         let ge_t = 1588508143000;
         let ge = Local.timestamp_millis(ge_t);
         dbg!(ge);
-        let para = KeyCondition {
-            id: "0".to_string(),
-            meta: "B:sale/order:1".to_string(),
-            key_gt: "".to_string(),
-            key_ge: "".to_string(),
-            key_lt: "".to_string(),
-            key_le: "".to_string(),
-            para: "".to_string(),
-            state_version: 0,
+        let para = InsCond {
+            id: 0,
             time_ge: None,
             time_lt: None,
-            limit: 100,
+            other: NoIdCond {
+                meta: "B:sale/order:1".to_string(),
+                key_gt: "".to_string(),
+                key_ge: "".to_string(),
+                key_lt: "".to_string(),
+                key_le: "".to_string(),
+                para: "".to_string(),
+                state_version: 0,
+                limit: 100,
+            },
         };
         let dao = InstanceDaoImpl {};
 
@@ -398,22 +402,24 @@ mod test {
     #[ignore]
     async fn query_by_range() {
         env::set_var("DATABASE_URL", "mysql://root@localhost/nature");
-        let para = KeyCondition {
-            id: "0".to_string(),
-            meta: "".to_string(),
-            key_gt: "B:sale/order:1|".to_string(),
-            key_ge: "".to_string(),
-            key_lt: "B:sale/order:2|".to_string(),
-            key_le: "".to_string(),
-            para: "".to_string(),
-            state_version: 0,
+        let para = InsCond {
+            id: 0,
             time_ge: Some(
                 1596115430000,
             ),
             time_lt: Some(
                 1596115431000,
             ),
-            limit: 20,
+            other: NoIdCond {
+                meta: "".to_string(),
+                key_gt: "B:sale/order:1|".to_string(),
+                key_ge: "".to_string(),
+                key_lt: "B:sale/order:2|".to_string(),
+                key_le: "".to_string(),
+                para: "".to_string(),
+                state_version: 0,
+                limit: 20,
+            },
         };
         let dao = InstanceDaoImpl {};
 
@@ -429,7 +435,7 @@ mod test {
     async fn get_downstream_test() {
         env::set_var("DATABASE_URL", "mysql://root@localhost/nature");
 
-        let result = InstanceDaoImpl::get_downstream("B:finance/payment:1|1193619470850765623||0").await;
+        let result = InstanceDaoImpl::select_downstream("B:finance/payment:1|1193619470850765623||0").await;
         assert!(result.is_ok());
         let vec = result.unwrap();
         dbg!(&vec);
