@@ -22,15 +22,12 @@ pub async fn web_init() -> std::io::Result<()> {
     dotenv().ok();
     let _ = env_logger::init();
     HttpServer::new(|| {
-        let cors = Cors::default()
-            .allowed_origin(&CLIENT_URL)
-            .allow_any_method()
-            .allow_any_header();
+        let cors = Cors::permissive();
         App::new()
             .wrap(Logger::default())
             .wrap(cors)
             .configure(manager_config)
     })
-        .bind("127.0.0.1:".to_owned() + &SERVER_PORT).unwrap()
+        .bind("0.0.0.0:".to_owned() + &SERVER_PORT).unwrap()
         .run().await
 }
